@@ -6,11 +6,8 @@
 #
 #  Authors: Vasya Svintsov <v.svintsov@techokert.ru>
 
-import asyncio
-
 from aiohttp import ClientSession, ClientResponse
 from aiohttp.typedefs import StrOrURL
-from http_tools import HttpStatusCode
 
 from ..metrics_registry import MetricsRegistry
 
@@ -22,13 +19,12 @@ class MonitoredClientSession(ClientSession):
 
     async def _request(self, method: str, str_or_url: StrOrURL, **kwargs) -> ClientResponse:
         labels = {'method': method.upper(), 'url': str_or_url}
-        except_labels = {'status_code': None, 'error': None}
-        with self._metrics.track('http_client__requests', labels, except_labels=except_labels):
+        with self._metrics.track('http_client__requests', labels) as tracker:
             try:
                 response = await super()._request(method, str_or_url, **kwargs)
-                labels['status_code'] = response.status
+                tracker.labels['status_code'] = response.status
             except Exception as er:
-                labels['error'] = type(er).__name__
+                tracker.labels['error'] = type(er).__name__
                 raise
         self._metrics.counter('http_client__input_traffic', labels).inc(response.content_length or 0)
         return response
